sleep_indefinitely_for_unit_tests

Function sleep_indefinitely_for_unit_tests 

pub fn sleep_indefinitely_for_unit_tests(py: Python<'_>) -> PyResult<()>
A test function that sleeps indefinitely in a loop. This is used for testing signal handling in signal_safe_block_on. The function will sleep forever until interrupted by a signal.