pub fn sleep_indefinitely_for_unit_tests(py: Python<'_>) -> PyResult<()>Expand description
A test function that sleeps indefinitely in a loop. This is used for testing signal handling in signal_safe_block_on. The function will sleep forever until interrupted by a signal.